<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        class="j-table-force-nowrap"
        :scroll="{x:true}"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
        :customRow="clickThenSelect"
        @change="handleTableChange">

        <template slot="htmlSlot" slot-scope="text">
          <div v-html="text"></div>
        </template>
        <template slot="imgSlot" slot-scope="text,record">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
          <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt="" style="max-width:80px;font-size: 12px;font-style: italic;"/>
        </template>
        <template slot="fileSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)">
            下载
          </a-button>
        </template>

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)" v-if="record.status==='created'||record.status==='rejected'">编辑</a>
          <a-divider type="vertical" v-if="record.status==='created'||record.status==='rejected'"/>
          <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)" v-if="record.status==='created'||record.status==='rejected'">
              <a>删除</a>
          </a-popconfirm>
          <a-divider type="vertical" v-if="record.status==='created'||record.status==='rejected'"/>
          <a-popconfirm title="提交后不可撤回，确定提交吗?" @confirm="() => handleSubmit(record)" v-if="record.status==='created'||record.status==='rejected'">
              <a>提交</a>
          </a-popconfirm>
          <a-divider type="vertical" v-if="record.status==='created'||record.status==='rejected'"/>
          <a-popconfirm title="通过后不可撤销，确定通过吗?" @confirm="() => handleAudit(record)" v-if="record.status==='submitted'">
              <a>通过</a>
          </a-popconfirm>
          <a-divider type="vertical" v-if="record.status==='submitted'"/>
          <a-popconfirm title="确定驳回吗?" @confirm="() => handleReject(record)" v-if="record.status==='submitted'">
              <a>驳回</a>
          </a-popconfirm>
          <a-divider type="vertical" v-if="record.status==='submitted'"/>
          <a-popconfirm title="下发后不可撤销，确定下发吗?" @confirm="() => handleDistrbute(record)" v-if="record.status==='passed'">
              <a>下发</a>
          </a-popconfirm>
        </span>

      </a-table>
    </div>

    <a-tabs defaultActiveKey="1">
      <a-tab-pane tab="保养计划明细" key="1" >
        <EquipmentMaintenancePlanDetailList :mainId="equipmentMaintenancePlanDetailMainId" />
      </a-tab-pane>
    </a-tabs>

    <equipmentMaintenancePlan-modal ref="modalForm" @ok="modalFormOk"></equipmentMaintenancePlan-modal>
  </a-card>
</template>

<script>

  import { JeecgListMixin } from '@/mixins/JeecgListMixin'
  import EquipmentMaintenancePlanModal from './modules/maintenancePlan/EquipmentMaintenancePlanModal'
  import { getAction } from '@/api/manage'
  import EquipmentMaintenancePlanDetailList from './EquipmentMaintenancePlanDetailList'
  import '@/assets/less/TableExpand.less'
import { putAction } from '../../api/manage'

  export default {
    name: "EquipmentMaintenancePlanList",
    mixins:[JeecgListMixin],
    components: {
      EquipmentMaintenancePlanDetailList,
      EquipmentMaintenancePlanModal
    },
    data () {
      return {
        description: '保养计划管理页面',
        // 表头
        columns: [
          {
            title:'计划单号',
            align:"center",
            dataIndex: 'num',
          },
          {
            title:'计划单类型',
            align:"center",
            dataIndex: 'type_dictText',
            width:200,
          },
          {
            title:'计划单状态',
            align:"center",
            dataIndex: 'status_dictText',
            width:200,
          },
          {
            title:'设备数量',
            align:"center",
            dataIndex: 'equipNo',
            width:200,
          },
          {
            title:'创建人',
            align:"center",
            dataIndex: 'createBy',
            width:200,
          },
          {
            title:'创建时间',
            align:"center",
            dataIndex: 'createTime',
            customRender:function (text) {
              return !text?"":(text.length>10?text.substr(0,10):text)
            },
            width:200,
          },
          {
            title:'修改人',
            align:"center",
            dataIndex: 'updateBy',
             width:200,
          },
          {
            title:'修改时间',
            align:"center",
            dataIndex: 'updateTime',
            customRender:function (text) {
              return !text?"":(text.length>10?text.substr(0,10):text)
            },
            width:200,
          },
          {
            title: '操作',
            dataIndex: 'action',
            align:"center",
            fixed:"right",
            width:200,
            scopedSlots: { customRender: 'action' },
          }
        ],
        url: {
          list: "/eam/equipmentMaintenancePlan/list",
          delete: "/eam/equipmentMaintenancePlan/delete",
          deleteBatch: "/eam/equipmentMaintenancePlan/deleteBatch",
          exportXlsUrl: "/eam/equipmentMaintenancePlan/exportXls",
          importExcelUrl: "eam/equipmentMaintenancePlan/importExcel",
          submit:"eam/equipmentMaintenancePlan/submit",
          reject:"eam/equipmentMaintenancePlan/reject",
          distrbute:"eam/equipmentMaintenancePlan/distrbute",
          audit:"eam/equipmentMaintenancePlan/audit"
        },
        dictOptions:{
        },
        /* 分页参数 */
        ipagination:{
          current: 1,
          pageSize: 5,
          pageSizeOptions: ['5', '10', '50'],
          showTotal: (total, range) => {
            return range[0] + "-" + range[1] + " 共" + total + "条"
          },
          showQuickJumper: true,
          showSizeChanger: true,
          total: 0
        },
        selectedMainId:'',
        superFieldList:[],
        equipmentMaintenancePlanDetailMainId: '',
      }
    },
    created() {
      this.getSuperFieldList();
    },
    computed: {
      importExcelUrl: function(){
        return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
      }
    },
    methods: {
      initDictConfig(){
      },
      clickThenSelect(record) {
        return {
          on: {
            click: () => {
              this.onSelectChange(record.id.split(","), [record]);
            }
          }
        }
      },
      onClearSelected() {
        this.selectedRowKeys = [];
        this.selectionRows = [];
        this.selectedMainId=''
      },
      onSelectChange(selectedRowKeys, selectionRows) {
        this.selectedMainId=selectedRowKeys[0]
        this.selectedRowKeys = selectedRowKeys;
        this.selectionRows = selectionRows;
        this.equipmentMaintenancePlanDetailMainId = selectionRows[0]['id']
      },
      loadData(arg) {
        if(!this.url.list){
          this.$message.error("请设置url.list属性!")
          return
        }
        //加载数据 若传入参数1则加载第一页的内容
        if (arg === 1) {
          this.ipagination.current = 1;
        }
        this.onClearSelected()
        var params = this.getQueryParams();//查询条件
        this.loading = true;
        getAction(this.url.list, params).then((res) => {
          if (res.success) {
            this.dataSource = res.result.records;
            this.ipagination.total = res.result.total;
          }
          if(res.code===510){
            this.$message.warning(res.message)
          }
          this.loading = false;
        })
      },
      getSuperFieldList(){
        let fieldList=[];
        fieldList.push({type:'string',value:'num',text:'计划单号',dictCode:''})
        fieldList.push({type:'string',value:'type',text:'计划单类型（数据字典：maintenance_plan_type）',dictCode:''})
        fieldList.push({type:'string',value:'status',text:'计划单状态(数据字典：maintenance_plan_type)',dictCode:''})
        fieldList.push({type:'int',value:'equipNo',text:'设备数量',dictCode:''})
        fieldList.push({type:'string',value:'createBy',text:'createBy',dictCode:''})
        fieldList.push({type:'date',value:'createTime',text:'createTime'})
        fieldList.push({type:'string',value:'updateBy',text:'updateBy',dictCode:''})
        fieldList.push({type:'date',value:'updateTime',text:'updateTime'})
        this.superFieldList = fieldList
      },
      handleSubmit(record){
         putAction(this.url.submit,record).then(res=>{
             if(res.success){
                this.$message.success("操作成功");
             }else{
                this.$message.success("操作失败");
             }
         })
      },
      handleAudit(record){
         putAction(this.url.audit,record).then(res=>{
          if(res.success){
                this.$message.success("操作成功");
             }else{
                this.$message.success("操作失败");
             }
         })
      },
      handleDistrbute(record){
        putAction(this.url.distrbute,record).then(res=>{
          if(res.success){
                this.$message.success("操作成功");
             }else{
                this.$message.success("操作失败");
             }
        })
      },
      handleReject(record){
        putAction(this.url.reject,record).then(res=>{
          if(res.success){
                this.$message.success("操作成功");
             }else{
                this.$message.success("操作失败");
             }
        })
      }
    }
  }
</script>
<style scoped>
  @import '~@assets/less/common.less'
</style>